@@ -10,7 +10,6 @@ from .ghostproject import *
 from .haveibeenpwned import *
 from .haveibeensold import *
 from .nuclearleaks import *
-from .pwnedpasswords import *
 from .shodan import *
 from .virustotal import *
 
@@ -20,10 +19,9 @@ from .ghostproject import __all__ as _gproj
 from .haveibeenpwned import __all__ as _hibp
 from .haveibeensold import __all__ as _hibs
 from .nuclearleaks import __all__ as _nleaks
-from .pwnedpasswords import __all__ as _ppswd
 from .shodan import __all__ as _shodan
 from .virustotal import __all__ as _vt
 
 
-__all__ = _censys + _dhd + _gproj + _hibp + _hibs + _nleaks + _ppswd + _shodan + _vt
+__all__ = _censys + _dhd + _gproj + _hibp + _hibs + _nleaks + _shodan + _vt
 
